@@ -1,9 +1,10 @@
 /* arp.c - ARP state machine */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
+#include <stdint.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -11,7 +12,7 @@
 #include <sys/types.h>
 #include <sys/socket.h> /* for linux/if_arp.h */
 #include <netinet/in.h> /* for ntohs, etc. */
-#include <linux/netdevice.h> /* for MAX_ADDR_LEN for if_arp.h */
+#define _LINUX_NETDEVICE_H /* very crude hack for glibc2 */
 #include <linux/if_arp.h>
 #include <linux/if_ether.h>
 #include <linux/atm.h>
@@ -70,15 +71,21 @@ static void discard_vcc(VCC *vcc)
 }
 
 
-void discard_entry(ENTRY *entry)
+void discard_vccs(ENTRY *entry)
 {
     VCC *vcc,*next;
 
-    STOP_TIMER(entry);
     for (vcc = entry->vccs; vcc; vcc = next) {
 	next = vcc->next;
 	discard_vcc(vcc);
     }
+}
+
+
+void discard_entry(ENTRY *entry)
+{
+    STOP_TIMER(entry);
+    discard_vccs(entry);
     if (!entry->itf) Q_REMOVE(unknown_incoming,entry);
     else {
 	if (entry == entry->itf->arp_srv) entry->itf->arp_srv = NULL;
@@ -118,7 +125,7 @@ static int want_arp_srv(ITF *itf)
 }
 
 
-static void vcc_detach(ENTRY *entry)
+void vcc_detach(ENTRY *entry)
 {
     ENTRY *walk;
 
@@ -138,7 +145,7 @@ static void vcc_detach(ENTRY *entry)
 }
 
 
-static void put_ip(unsigned char **here,unsigned long ip,unsigned char *len)
+static void put_ip(unsigned char **here,uint32_t ip,unsigned char *len)
 {
     if (!ip) {
 	*len = 0;
@@ -182,8 +189,8 @@ static const unsigned char llc_oui_arp[] = {
 	0x06 };
 
 
-static void send_arp(int fd,unsigned short op,unsigned long local_ip,
-  struct sockaddr_atmsvc *local_addr,unsigned long remote_ip,
+static void send_arp(int fd,unsigned short op,uint32_t local_ip,
+  struct sockaddr_atmsvc *local_addr,uint32_t remote_ip,
   struct sockaddr_atmsvc *remote_addr)
 {
     struct sockaddr_atmsvc local;
@@ -211,7 +218,7 @@ static void send_arp(int fd,unsigned short op,unsigned long local_ip,
 }
 
 
-static void arp_request(ITF *itf,unsigned long ip)
+static void arp_request(ITF *itf,uint32_t ip)
 {
     VCC *vcc;
 
@@ -233,7 +240,7 @@ static void arp_request(ITF *itf,unsigned long ip)
 static void inarp_for_itf(VCC *vcc,ITF *itf)
 {
     if (itf->local_ip) {
-	diag(COMPONENT,DIAG_DEBUG,"  on itf %d",itf->number);
+	diag(COMPONENT,DIAG_DEBUG,"  for itf %d",itf->number);
 	assert(vcc->entry);
 	send_arp(vcc->fd,ARPOP_InREQUEST,itf->local_ip,NULL,0,
 	  vcc->entry->svc ? vcc->entry->addr : NULL);
@@ -246,7 +253,7 @@ static void inarp_request(ENTRY *entry)
     VCC *vcc;
     ITF *itf;
 
-    diag(COMPONENT,DIAG_DEBUG,"sending InARP request");
+    diag(COMPONENT,DIAG_DEBUG,"sending an InARP request for each IP interface");
     for (vcc = entry->vccs; vcc; vcc = vcc->next)
 	if (!vcc->connecting)
 	    if (entry->itf) inarp_for_itf(vcc,entry->itf);
@@ -254,7 +261,7 @@ static void inarp_request(ENTRY *entry)
 }
 
 
-static void arp_nak(VCC *vcc,unsigned long src_ip,unsigned long tgt_ip,
+static void arp_nak(VCC *vcc,uint32_t src_ip,uint32_t tgt_ip,
   struct sockaddr_atmsvc *tgt_addr)
 {
     diag(COMPONENT,DIAG_DEBUG,"sending ARP NAK");
@@ -262,8 +269,8 @@ static void arp_nak(VCC *vcc,unsigned long src_ip,unsigned long tgt_ip,
 }
 
 
-static void arp_reply(VCC *vcc,unsigned long src_ip,
-  struct sockaddr_atmsvc *src_addr,unsigned long tgt_ip,
+static void arp_reply(VCC *vcc,uint32_t src_ip,
+  struct sockaddr_atmsvc *src_addr,uint32_t tgt_ip,
   struct sockaddr_atmsvc *tgt_addr)
 {
     if (!src_addr) {
@@ -275,7 +282,7 @@ static void arp_reply(VCC *vcc,unsigned long src_ip,
 }
 
 
-static void inarp_reply(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
+static void inarp_reply(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 {
     ITF *itf;
 
@@ -403,6 +410,7 @@ static void connect_me(ENTRY *entry)
     VCC *vcc;
     int fd;
 
+    assert(entry->addr->sas_family == AF_ATMSVC);
     if ((fd = connect_vcc((struct sockaddr *) entry->addr,&entry->qos,
       CLIP_DEFAULT_IDLETIMER)) < 0) return;
     vcc = alloc_t(VCC);
@@ -423,7 +431,7 @@ static void adjust_qos(ITF *itf,struct atm_qos *qos,int null_encap)
 }
 
 
-static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
+static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 {
     ENTRY *entry;
     ITF *itf;
@@ -541,7 +549,7 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
 }
 
 
-static void learn_nak(unsigned long ip)
+static void learn_nak(uint32_t ip)
 {
     ITF *itf;
     ENTRY *entry;
@@ -557,7 +565,7 @@ static void learn_nak(unsigned long ip)
 }
 
 
-void need_ip(int itf_num,unsigned long ip)
+void need_ip(int itf_num,uint32_t ip)
 {
     ITF *itf;
     ENTRY *entry;
@@ -631,7 +639,7 @@ static void set_addr(struct sockaddr_atmsvc *addr,void *num,void *sub,
 }
 
 
-static unsigned long get_ip(unsigned char *ptr)
+static uint32_t get_ip(unsigned char *ptr)
 {
     if (!ptr) return 0;
     /* awkward, but this way we avoid bus errors on architectures that
@@ -646,7 +654,7 @@ void incoming_arp(VCC *vcc,struct atmarphdr *hdr,int len)
     ENTRY *entry;
     void *sha,*ssa,*spa,*tha,*tsa,*tpa;
     struct sockaddr_atmsvc source,target;
-    unsigned long src_ip,tgt_ip;
+    uint32_t src_ip,tgt_ip;
     unsigned char *here;
 
     if (len < hdr->data-(unsigned char *) hdr) {
@@ -739,8 +747,8 @@ void incoming_arp(VCC *vcc,struct atmarphdr *hdr,int len)
 }
 
 
-static int ioctl_set_pvc(ITF *itf,unsigned long ip,
-  struct sockaddr_atmpvc *addr,const struct atm_qos *qos,int flags)
+static int ioctl_set_pvc(ITF *itf,uint32_t ip,struct sockaddr_atmpvc *addr,
+  const struct atm_qos *qos,int flags)
 {
     ENTRY *entry;
     VCC *vcc;
@@ -771,8 +779,8 @@ static int ioctl_set_pvc(ITF *itf,unsigned long ip,
 }
 
 
-static int ioctl_set_svc(ITF *itf,unsigned long ip,
-  struct sockaddr_atmsvc *addr,const struct atm_qos *qos,int flags)
+static int ioctl_set_svc(ITF *itf,uint32_t ip,struct sockaddr_atmsvc *addr,
+  const struct atm_qos *qos,int flags)
 {
     ENTRY *entry;
 
@@ -799,7 +807,7 @@ static int ioctl_set_svc(ITF *itf,unsigned long ip,
 }
 
 
-static int ioctl_delete(ITF *itf,unsigned long ip,int flags)
+static int ioctl_delete(ITF *itf,uint32_t ip,int flags)
 {
     ENTRY *entry,*walk,*next;
 
@@ -831,7 +839,7 @@ int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
 {
     ITF *itf;
     char buffer[MAX_ATM_ADDR_LEN+1];
-    unsigned long ip;
+    uint32_t ip;
     unsigned char *ipp;
 
     diag(COMPONENT,DIAG_DEBUG,"arp_ioctl 0x%08lx",cmd);
@@ -898,7 +906,7 @@ void vcc_failed(VCC *vcc)
 {
     ENTRY *entry,*next;
 
-    diag(COMPONENT,DIAG_DEBUG,"failed VCC 0x%08x",(unsigned long) vcc);
+    diag(COMPONENT,DIAG_DEBUG,"failed VCC 0x%p",vcc);
     Q_REMOVE(vcc->entry->vccs,vcc);
     if (!(vcc->entry->flags & ATF_ARPSRV) || vcc->entry->vccs) {
 	/* VCC is already closed */
@@ -922,7 +930,7 @@ void vcc_connected(VCC *vcc)
 {
     ENTRY *entry;
 
-    diag(COMPONENT,DIAG_DEBUG,"connected VCC 0x%08x",(unsigned long) vcc);
+    diag(COMPONENT,DIAG_DEBUG,"connected VCC 0x%p",vcc);
     if (!vcc->connecting)
 	diag(COMPONENT,DIAG_FATAL,"non-connecting VCC connected");
     vcc->connecting = 0;
@@ -942,7 +950,7 @@ void disconnect_vcc(VCC *vcc)
 {
     ENTRY *entry;
 
-    diag(COMPONENT,DIAG_DEBUG,"disconnected VCC0x%08x",(unsigned long) vcc);
+    diag(COMPONENT,DIAG_DEBUG,"disconnected VCC 0x%p",vcc);
     entry = vcc->entry;
     discard_vcc(vcc);
     if (entry) vcc_detach(entry);
@@ -951,7 +959,7 @@ void disconnect_vcc(VCC *vcc)
 
 void incoming_call(VCC *vcc)
 {
-    diag(COMPONENT,DIAG_DEBUG,"incoming VCC 0x%08x",(unsigned long) vcc);
+    diag(COMPONENT,DIAG_DEBUG,"incoming VCC 0x%p",vcc);
     START_TIMER(vcc->entry,REPLY);
     inarp_request(vcc->entry);
 }
