@@ -1,9 +1,10 @@
 /* io.c - I/O operations */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdio.h>
+#include <stdint.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -17,6 +18,7 @@
 #include <linux/atm.h>
 #include <linux/atmclip.h> /* for CLIP_DEFAULT_IDLETIMER */
 #include <linux/atmarp.h>
+#define _LINUX_NETDEVICE_H /* glibc2 */
 #include <linux/if_arp.h>
 
 #include "atm.h"
@@ -122,6 +124,8 @@ static void recv_kernel(void)
 	case act_down:
 	    itf_down(ctrl->itf_num);
 	    break;
+	case act_change:
+	    itf_change(ctrl->itf_num);
 	case act_ioctl:
 	    ctrl->type = act_complete;
 	    ctrl->arg = arp_ioctl(ctrl->itf_num,ctrl->arg,(struct atmarpreq *)
@@ -323,8 +327,7 @@ static void complete_connect(VCC *vcc)
     struct sockaddr_atmsvc dummy;
 
     if (!vcc->connecting)
-	diag(COMPONENT,DIAG_FATAL,"connecting non-connecting VCC 0x%08x",
-	  (unsigned long) vcc);
+	diag(COMPONENT,DIAG_FATAL,"connecting non-connecting VCC 0x%p",vcc);
     memset(&dummy,0,sizeof(dummy));
     if (!connect(vcc->fd,(struct sockaddr *) &dummy,sizeof(dummy))) {
 	if (ioctl(vcc->fd,ATMARP_MKIP,CLIP_DEFAULT_IDLETIMER) < 0) {
@@ -443,7 +446,7 @@ void send_packet(int fd,void *data,int length)
 }
 
 
-int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask,int *mtu)
+int ip_itf_info(int number,uint32_t *ip,uint32_t *netmask,int *mtu)
 {
     struct ifreq req;
     unsigned char *p1,*p2;
