@@ -1,11 +1,16 @@
 /* itf.c - IP interface registry */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
+#include <stdint.h>
 #include <string.h>
+#include <sys/types.h>
 #include <linux/atmclip.h>
+#include <sys/socket.h>
+#define _LINUX_NETDEVICE_H /* glibc2 */
+#include <linux/if_arp.h>
 
 #include "atmd.h"
 
@@ -28,7 +33,7 @@ ITF *lookup_itf(int number)
 }
 
 
-ITF *lookup_itf_by_ip(unsigned long ip)
+ITF *lookup_itf_by_ip(uint32_t ip)
 {
     ITF *itf;
 
@@ -50,11 +55,10 @@ void itf_up(int number)
     ITF *itf;
 
     diag(COMPONENT,DIAG_DEBUG,"ITF UP %d",number);
-    for (itf = itfs; itf; itf = itf->next)
-	if (itf->number == number) {
-	    diag(COMPONENT,DIAG_ERROR,"interface is already active");
-	    return;
-	}
+    if (lookup_itf(number)) {
+	diag(COMPONENT,DIAG_ERROR,"interface is already active");
+	return;
+    }
     itf = alloc_t(ITF);
     if (ip_itf_info(number,&itf->local_ip,&itf->netmask,&itf->mtu) < 0) {
 	free(itf);
@@ -71,18 +75,10 @@ void itf_up(int number)
 }
 
 
-void itf_down(int number)
+static void itf_bring_down(ITF *itf)
 {
-    ITF *itf;
     ENTRY *entry,*next;
 
-    diag(COMPONENT,DIAG_DEBUG,"ITF DOWN %d",number);
-    for (itf = itfs; itf; itf = itf->next)
-	if (itf->number == number) break;
-    if (!itf) {
-	diag(COMPONENT,DIAG_ERROR,"no such interface");
-	return;
-    }
     for (entry = itf->table; entry; entry = next) {
 	next = entry->next;
 	discard_entry(entry);
@@ -90,3 +86,55 @@ void itf_down(int number)
     Q_REMOVE(itfs,itf);
     free(itf);
 }
+
+
+void itf_down(int number)
+{
+    ITF *itf;
+
+    diag(COMPONENT,DIAG_DEBUG,"ITF DOWN %d",number);
+    itf = lookup_itf(number);
+    if (!itf) {
+	diag(COMPONENT,DIAG_ERROR,"no such interface");
+	return;
+    }
+    itf_bring_down(itf);
+}
+
+
+void itf_change(int number)
+{
+    ITF *itf;
+    ENTRY *entry,*next,*disconnected;
+    uint32_t local_ip,netmask;
+    int mtu;
+
+    diag(COMPONENT,DIAG_DEBUG,"ITF CHANGE %d",number);
+    itf = lookup_itf(number);
+    if (!itf) {
+	diag(COMPONENT,DIAG_ERROR,"no such interface");
+	return;
+    }
+    if (ip_itf_info(number,&local_ip,&netmask,&mtu) < 0) {
+	itf_bring_down(itf);
+	return;
+    }
+    disconnected = NULL;
+    for (entry = itf->table; entry; entry = next) {
+	next = entry->next;
+	if ((entry->flags & ATF_PERM) &&
+	  !((entry->ip ^ local_ip) & (netmask | itf->netmask))) continue;
+	if ((entry->flags & ATF_ARPSRV) && !((entry->ip ^ local_ip) & netmask))
+	  {
+	    disconnected = entry;
+	    discard_vccs(entry);
+	    /* @@@ should adjust max_sdu if mtu changed */
+	    continue;
+	}
+	discard_entry(entry);
+    }
+    itf->local_ip = local_ip;
+    itf->netmask = netmask;
+    itf->mtu = mtu;
+    if (disconnected) vcc_detach(disconnected);
+}
