@@ -1,9 +1,10 @@
 /* table.c - ATMARP table */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdio.h>
+#include <stdint.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -40,7 +41,7 @@ ENTRY *alloc_entry(int svc)
 }
 
 
-ENTRY *lookup_ip(const ITF *itf,unsigned long ip)
+ENTRY *lookup_ip(const ITF *itf,uint32_t ip)
 {
     ENTRY *walk;
 
