@@ -1,11 +1,12 @@
 /* table.h - ATMARP table */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #ifndef TABLE_H
 #define TABLE_H
 
+#include <stdint.h>
 #include <linux/atm.h>
 
 #include "atmd.h"
@@ -34,7 +35,7 @@ typedef enum {
 typedef struct _entry {
     ADDR_STATE state;
     int svc;
-    unsigned long ip;
+    uint32_t ip;
     struct sockaddr_atmsvc *addr; /* NULL if none */
     struct atm_qos qos;
     int flags;
@@ -47,8 +48,8 @@ typedef struct _entry {
 } ENTRY;
 
 typedef struct _itf {
-    unsigned long local_ip; /* @@@ */
-    unsigned long netmask;
+    uint32_t local_ip; /* @@@ */
+    uint32_t netmask;
     int number;
     int mtu;
     struct atm_qos qos; /* default QOS */
@@ -75,7 +76,7 @@ extern int pretty,merge;
 
 ENTRY *alloc_entry(int svc);
 
-ENTRY *lookup_ip(const ITF *itf,unsigned long ip);
+ENTRY *lookup_ip(const ITF *itf,uint32_t ip);
 ENTRY *lookup_addr(const ITF *itf,const struct sockaddr_atmsvc *addr);
 ENTRY *lookup_incoming(const struct sockaddr_atmsvc *addr);
 
