@@ -21,6 +21,7 @@
 #define DEFAULT_PORT 1997
 #define MSG "just testing"
 #define BUF_SIZE 100
+#define MAX_QOS 16
 
 
 static int verbose = 0;
@@ -50,8 +51,8 @@ static void mismatch(const char *msg,int size)
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [-a atm_host[/qos]] [-p port] [-v] [host] "
-      "sequence\n",name);
+    fprintf(stderr,"usage: %s [-a atm_host[/qos[/qos ... ]]] [-p port] [-v] "
+      "[host] sequence\n",name);
     fprintf(stderr,"sequence consists of the following characters:\n");
     fprintf(stderr,"  a accept (and close listening socket)\n");
     fprintf(stderr,"  b bind\n");
@@ -61,6 +62,7 @@ static void usage(const char *name)
     fprintf(stderr,"  f arequipa_close\n");
     fprintf(stderr,"  h hang (loop forever)\n");
     fprintf(stderr,"  l listen\n");
+    fprintf(stderr,"  m modify\n");
     fprintf(stderr,"  o connect\n");
     fprintf(stderr,"  p arequipa_preset\n");
     fprintf(stderr,"  r read\n");
@@ -72,29 +74,43 @@ static void usage(const char *name)
 
 int main(int argc,char **argv)
 {
+    struct atm_qos qos[MAX_QOS];
     struct sockaddr_atmsvc addr_atm;
     struct sockaddr_in addr_in;
-    struct atm_qos qos;
     const char *port;
     char *here,*end,*walk;
     int opt_a,c,s;
+    int qos_avail,curr_qos;
 
     opt_a = 0;
     port = NULL;
+    qos_avail = 0;
     while ((c = getopt(argc,argv,"a:p:v")) != EOF)
 	switch (c) {
 	    case 'a':
 		memset(&addr_atm,0,sizeof(addr_atm));
 		here = strchr(optarg,'/');
 		if (!(here = strchr(optarg,'/'))) {
-		    memset(&qos,0,sizeof(qos));
-		    qos.txtp.traffic_class = qos.rxtp.traffic_class = ATM_UBR;
+		    memset(&qos,0,sizeof(struct atm_qos));
+		    qos->txtp.traffic_class = qos->rxtp.traffic_class = ATM_UBR;
+		    qos_avail = 1;
 		}
 		else {
+		    qos_avail = 0;
 		    *here++ = 0;
-		    if (text2qos(here,&qos,0) < 0) {
-			fprintf(stderr,"invalid QOS specification: %s\n",here);
-			return 1;
+		    for (here = strtok(here,"/"); here;
+		      here = strtok(NULL,"/")) {
+			if (qos_avail == MAX_QOS) {
+			    fprintf(stderr,"only %d QOS specs configured\n",
+			      MAX_QOS);
+			    return 1;
+			}
+			if (text2qos(here,qos+qos_avail,0) < 0) {
+			    fprintf(stderr,"invalid QOS specification: %s\n",
+			      here);
+			    return 1;
+			}
+			qos_avail++;
 		    }
 		}
 		if (text2atm(optarg,(struct sockaddr *) &addr_atm,
@@ -140,6 +156,7 @@ int main(int argc,char **argv)
 	    addr_in.sin_port = se->s_port;
 	}
     }
+    curr_qos = 0;
     if (*argv[argc-1] != 's') {
 	fprintf(stderr,"sequence must start with \"s\"\n");
 	return 1;
@@ -185,6 +202,16 @@ int main(int argc,char **argv)
 		say("listen");
 		if (listen(s,1) < 0) fail("listen");
 		break;
+	    case 'm':
+		if (curr_qos == qos_avail) {
+		    fprintf(stderr,"no QOS spec left for "
+		      "arequipa_renegotiate\n");
+		    return 1;
+		}
+		say("modify (renegotiate)");
+		if (arequipa_renegotiate(s,qos+curr_qos++) < 0)
+		    fail("arequipa_renegotiate");
+		break;
 	    case 'o':
 		say("open (connect)");
 		if (connect(s,(struct sockaddr *) &addr_in,sizeof(addr_in)) < 0)
@@ -196,8 +223,12 @@ int main(int argc,char **argv)
 		      "arequipa_preset\n");
 		    return 1;
 		}
+		if (curr_qos == qos_avail) {
+		    fprintf(stderr,"no QOS spec left for arequipa_preset\n");
+		    return 1;
+		}
 		say("arequipa_preset");
-		if (arequipa_preset(s,&addr_atm,&qos) < 0)
+		if (arequipa_preset(s,&addr_atm,qos+curr_qos++) < 0)
 		    fail("arequipa_preset");
 		break;
 	    case 'r':
