@@ -8,8 +8,7 @@
 #include <linux/atm.h>
 #include <linux/atmdev.h>
 #include <linux/sonet.h>
-
-#include "/usr/src/linux/drivers/atm/eni.h"
+#include <linux/atm_eni.h>
 
 
 static void usage(const char *name)
