@@ -75,7 +75,7 @@ void ilmi_loop(int fd, int itf)
   poll_message = create_poll_message();
   set_message = create_set_message();
   set_oid = &((VarBind *) FIRST_LIST_ELMT(set_message->data->a.set_request->variable_bindings))->name;
-  esi_oid = get_esi(fd);
+  esi_oid = get_esi(fd,itf);
   coldstart_message = create_coldstart_message();
   in_message = alloc_t(Message);
 
