@@ -1,6 +1,6 @@
 /* atmarp.c - RFC1577 ATMARP control */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -15,12 +15,11 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <net/if.h> /* struct ifreq */
+#include <net/if_arp.h>
 
 #include <linux/atm.h>
 #include <linux/atmarp.h>
 #include <linux/atmclip.h>
-#include <linux/netdevice.h> /* for MAX_ADDR_LEN for if_arp.h */
-#include <linux/if_arp.h> /* for ATF_PERM and ATF_PUBL */
 #include <linux/version.h>
 
 #include "atm.h"
