@@ -64,6 +64,7 @@ int
 atm_create_socket(unsigned char codepoint, const AtmAddr_t *our_addr)
 { 
   struct sockaddr_atmsvc server;
+  struct atm_sap atmsap;
   struct atm_blli blli;
   struct atm_qos qos;
   int fd, ret;
@@ -80,7 +81,6 @@ atm_create_socket(unsigned char codepoint, const AtmAddr_t *our_addr)
   memset(&qos, 0, sizeof(qos));
   server.sas_family = AF_ATMSVC;
   memcpy(server.sas_addr.prv, our_addr, ATM_ESA_LEN);
-  server.sas_addr.blli = &blli;
   qos.aal = ATM_AAL5;
   qos.txtp.traffic_class = ATM_UBR;
   qos.txtp.max_sdu = 1516;
@@ -100,7 +100,16 @@ atm_create_socket(unsigned char codepoint, const AtmAddr_t *our_addr)
     close(fd);
     return -1;
   }
-  disp_sockaddr(&server);
+  disp_sockaddr(&server, &blli);
+
+  memset(&atmsap, 0, sizeof(struct atm_sap));
+  atmsap.blli[0] = blli;
+  if (setsockopt(fd,SOL_ATM,SO_ATMSAP,&atmsap,sizeof(atmsap)) < 0) {
+    dump_error(&atm_unit, "setsockop(SO_ATMSAP)");
+    (void) close(fd);
+    return -1;
+  }
+ 
   ret = bind(fd, (struct sockaddr *)&server, len);
   if (ret <0) {
     dump_error(&atm_unit, "bind");
@@ -121,6 +130,7 @@ atm_connect_back(const AtmAddr_t *our_addr, const Conn_t *conn,
 		 unsigned char codepoint)
 {
   struct sockaddr_atmsvc address;
+  struct atm_sap atmsap;
   struct atm_blli blli;
   struct atm_qos qos;
   int fd, ret;
@@ -149,7 +159,7 @@ atm_connect_back(const AtmAddr_t *our_addr, const Conn_t *conn,
   address.sas_family = AF_ATMSVC;
   memcpy(address.sas_addr.prv, our_addr, sizeof(AtmAddr_t));
 
-  disp_sockaddr(&address);
+  disp_sockaddr(&address, &blli);
 
   ret = bind(fd, (struct sockaddr *)&address, len);
   if (ret <0) {
@@ -164,7 +174,6 @@ atm_connect_back(const AtmAddr_t *our_addr, const Conn_t *conn,
     close(fd);
     return -1;
   }
-  address.sas_addr.blli = &blli;
   memset(&blli, 0, sizeof(blli));
   blli.l3_proto = ATM_L3_TR9577;
   blli.l3.tr9577.ipi = NLPID_IEEE802_1_SNAP;
@@ -174,8 +183,16 @@ atm_connect_back(const AtmAddr_t *our_addr, const Conn_t *conn,
   blli.l3.tr9577.snap[3] = 0x00;
   blli.l3.tr9577.snap[4] = codepoint;
   
-  disp_sockaddr(&address);
+  disp_sockaddr(&address, &blli);
 
+  memset(&atmsap, 0, sizeof(struct atm_sap));
+  atmsap.blli[0] = blli;
+  if (setsockopt(fd,SOL_ATM,SO_ATMSAP,&atmsap,sizeof(atmsap)) < 0) {
+    dump_error(&atm_unit, "setsockop(SO_ATMSAP)");
+    (void) close(fd);
+    return -1;
+  }
+  
   ret = connect(fd, (struct sockaddr*)&address,sizeof(struct sockaddr_atmsvc));
   if (ret < 0) {
     dump_error(&atm_unit, "connect");
