@@ -24,6 +24,7 @@ int
 atm_create_socket(unsigned char codepoint, const unsigned char *our_addr)
 { 
   struct sockaddr_atmsvc server;
+  struct atm_sap atmsap;
   struct atm_blli blli;
   struct atm_qos qos;
   int fd, ret;
@@ -41,7 +42,6 @@ atm_create_socket(unsigned char codepoint, const unsigned char *our_addr)
   server.sas_family = AF_ATMSVC;
   if (our_addr)
     memcpy(server.sas_addr.prv, our_addr, ATM_ESA_LEN);
-  server.sas_addr.blli = &blli;
   qos.aal = ATM_AAL5;
   qos.txtp.traffic_class = ATM_UBR;
   qos.txtp.max_sdu = 1516;
@@ -61,6 +61,15 @@ atm_create_socket(unsigned char codepoint, const unsigned char *our_addr)
     close(fd);
     return -1;
   }
+
+  memset(&atmsap, 0, sizeof(struct atm_sap));
+  atmsap.blli[0] = blli;
+  if (setsockopt(fd,SOL_ATM,SO_ATMSAP,&atmsap,sizeof(atmsap)) < 0) {
+    perror("setsockop(SO_ATMSAP)");
+    (void) close(fd);
+    return -1;
+  }
+
   ret = bind(fd, (struct sockaddr *)&server, len);
   if (ret <0) {
     perror("bind(fd, ...)");
