@@ -45,21 +45,25 @@ static int data_handler(const Event_t *event, void *funcdata);
 static int timer_handler(const Event_t *event, void *funcdata);
 static void conn_main(void);
 
-static int join(const Conn_t *conn);
-static int join_ok(const Conn_t *conn);
-static int join_bad(const Conn_t *conn);
-static int join_close(const Conn_t *conn);
-static int join_expire(const Conn_t *conn);
-static int idle_bad(const Conn_t *conn);
-static int topology_request(const Conn_t *conn);
+/*
+ * as in connect_bus.c had to remove const qualifiers since
+ * not every function honored it
+ */
+static int join(Conn_t *conn);
+static int join_ok(Conn_t *conn);
+static int join_bad(Conn_t *conn);
+static int join_close(Conn_t *conn);
+static int join_expire(Conn_t *conn);
+static int idle_bad(Conn_t *conn);
+static int topology_request(Conn_t *conn);
 
-static int register_req(const Conn_t *conn);
-static int unregister_req(const Conn_t *conn);
+static int register_req(Conn_t *conn);
+static int unregister_req(Conn_t *conn);
 
-static int arp_find(const Conn_t *conn);
-static int arp_forward_response(const Conn_t *conn);
+static int arp_find(Conn_t *conn);
+static int arp_forward_response(Conn_t *conn);
 
-static int forward_flush_response(const Conn_t *conn);
+static int forward_flush_response(Conn_t *conn);
 
 static int is_multicast(const LaneDestination_t *to_detect);
 static int proper_request(void);
@@ -558,7 +562,7 @@ is_proxy(void)
  * State transition functions
  */
 static int
-join(const Conn_t *conn)
+join(Conn_t *conn)
 {
   int timeout;
   int rfd;
@@ -579,9 +583,9 @@ join(const Conn_t *conn)
 }
 
 static int
-join_ok(const Conn_t *conn)
+join_ok(Conn_t *conn)
 {
-  Reg_t *rtmp;
+  Reg_t *rtmp = NULL;   /* silence gcc 2.7.2.1 */
   Lecdb_t *ltmp; 
   const char *elanname;
 
@@ -675,7 +679,7 @@ join_ok(const Conn_t *conn)
 }
 
 static int
-join_bad(const Conn_t *conn)
+join_bad(Conn_t *conn)
 {
   Debug_unit(&conn_unit, "Join_bad called");
   dump_conn(conn);
@@ -688,7 +692,7 @@ join_bad(const Conn_t *conn)
 }
 
 static int
-idle_bad(const Conn_t *conn)
+idle_bad(Conn_t *conn)
 {
   Debug_unit(&conn_unit, "Idle bad called");
   dump_conn(conn);
@@ -697,7 +701,7 @@ idle_bad(const Conn_t *conn)
 }
 
 static int
-join_close(const Conn_t *conn)
+join_close(Conn_t *conn)
 {
   Lecdb_t *tmp;
 
@@ -735,7 +739,7 @@ join_close(const Conn_t *conn)
 }
 
 static int
-join_expire(const Conn_t *conn)
+join_expire(Conn_t *conn)
 {
   
   Debug_unit(&conn_unit, "Join_expire called");
@@ -746,7 +750,7 @@ join_expire(const Conn_t *conn)
 }
 
 static int
-register_req(const Conn_t *conn)
+register_req(Conn_t *conn)
 {
   Reg_t *tmp;
   Lecdb_t *ltmp;
@@ -794,7 +798,7 @@ register_req(const Conn_t *conn)
 }
 
 static int
-unregister_req(const Conn_t *conn)
+unregister_req(Conn_t *conn)
 {
   Reg_t *tmp;
   Lecdb_t *ltmp;
@@ -838,7 +842,7 @@ unregister_req(const Conn_t *conn)
 }
 
 static int
-arp_find(const Conn_t *conn)
+arp_find(Conn_t *conn)
 {
   Reg_t *tmp;
   Lecdb_t *ltmp;
@@ -882,7 +886,7 @@ arp_find(const Conn_t *conn)
 }
 
 static int
-arp_forward_response(const Conn_t *conn)
+arp_forward_response(Conn_t *conn)
 {
   int a;
   Conn_t *tmp;
@@ -902,7 +906,7 @@ arp_forward_response(const Conn_t *conn)
 }
 
 static int
-forward_flush_response(const Conn_t *conn)
+forward_flush_response(Conn_t *conn)
 {
   int a;
 
@@ -919,7 +923,7 @@ forward_flush_response(const Conn_t *conn)
 }
 
 static int
-topology_request(const Conn_t *conn)
+topology_request(Conn_t *conn)
 {
   int a;
 
