@@ -54,7 +54,7 @@
 #include "g_types.h"
 #include "cm_sap.h"
 #include "lec.h"
-#include "atm.h"
+#include "lane_atm.h"
 #include "atmsap.h"
 #include "cm.h"
 #include "g_event.h"
@@ -284,6 +284,7 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
   int ret;
   struct sockaddr_atmsvc us;
   struct atm_blli blli;
+  struct atm_sap atmsap;
 
   EVENT(EM_EVENT,("Outgoing call setup\n"));
   
@@ -314,7 +315,7 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
   }
   
   /* Create socket */
-  s = socket(PF_ATMSVC, SOCK_DGRAM, ATM_AAL5);
+  s = socket(PF_ATMSVC, SOCK_DGRAM, 0);
   if (s<0) {
     EVENT(EM_NERR,("socket creation failure:%s\n",strerror(errno)));
     if (is_data_direct(p_conn_info)) {
@@ -337,8 +338,6 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
     return STATUS_K_ATM_RESOURCES;
   }
   
-  /* Create local binding point */
-  us.sas_addr.blli = &blli;
   /* Copy blli information */
   memcpy(&blli, &(p_conn_info->blli), sizeof(struct atm_blli));
   /* Set traffic parameters */
@@ -357,7 +356,16 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
   us.sas_family = p_conn_info->addr.sas_family;
 
   if (EMASK & EM_DEBUG)
-    disp_sockaddr(&us);
+    disp_sockaddr(p_conn_info);
+
+  /* new since 0.33-pre-x, SO_ATMSAP */
+  memset(&atmsap, 0, sizeof(struct atm_sap));
+  atmsap.blli[0] = blli;
+  if (setsockopt(s,SOL_ATM,SO_ATMSAP,&atmsap,sizeof(atmsap)) < 0) {
+    EVENT(EM_NERR,("conn.c::cm_sap_svc_setup setsockop(SO_ATMSAP)\n"));
+    (void) close(s);
+    return -1;
+  }
 
   ret = bind(s, (struct sockaddr *)&us, sizeof(us));
   if (ret<0) {
@@ -372,7 +380,7 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
   }
 
   if (EMASK & EM_DEBUG)
-    disp_sockaddr(&(p_conn_info->addr));
+    disp_sockaddr(p_conn_info);
 
   EVENT(EM_EVENT,("Call to %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x %2.2x\n",
 		  p_conn_info->addr.sas_addr.prv[0]&0xff,
@@ -534,12 +542,13 @@ cm_sap_link_status_get(HANDLE sap_handle, ATM_LINK_STATE *p_link_state)
   EVENT(EM_DEBUG,("Cm_sap_link_status_get\n"));
   assert(sap_handle);
 
-  if ((s=socket(AF_ATMSVC, SOCK_DGRAM, ATM_AAL5))<0) {
+  if ((s=socket(AF_ATMSVC, SOCK_DGRAM, 0))<0) {
     /* Socket creation failure -> not capable of running LE */
     EVENT(EM_SERR,("Not capable of creating ATM socket."));
     *p_link_state = LINK_DOWN;
     exit(-1);
   }
+  close(s);
   *p_link_state = LINK_SIG_UP;
 }
 
@@ -547,7 +556,6 @@ void
 svcinit_conn_info(CONN_INFO *p_svc_conn_info)
 {
   memset(p_svc_conn_info,0,sizeof(CONN_INFO));
-  p_svc_conn_info->addr.sas_addr.blli = &(p_svc_conn_info->blli);
 }
 
 /* Callbacks for connections */
@@ -620,12 +628,12 @@ void
 conn_get_fds(fd_set *fds)
 {
   Conn_t *conn;
-  char *buff, *ch;
+  char *buff = NULL, *ch = NULL;  /* once again, silence gcc 2.7.2.1 */
 
   conn = connlist;
 
   if (EMASK & EM_DEBUG) {
-    buff = (char*)mem_alloc(EINST,1024);
+    buff = (char*)mem_alloc(EINST, 1024);
     ch = buff;
   }
   while (conn) {
@@ -647,7 +655,7 @@ void
 conn_get_connecting_fds(fd_set *fds)
 {
   Conn_t *conn;
-  char *buff, *ch;
+  char *buff = NULL, *ch = NULL;  /* once again, silence gcc 2.7.2.1 */
 
   conn = connlist;
 
@@ -879,11 +887,12 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
   int fd, ret, len;
   Conn_t *conn;
   CONN_INFO *conn_info;
+  struct atm_sap atmsap;
 
   conn_info = (CONN_INFO *)mem_alloc(EINST, sizeof(CONN_INFO));
 
   EVENT(EM_DEBUG,("conn_create_listensocket\n"));
-  fd = socket(PF_ATMSVC, SOCK_DGRAM, ATM_AAL5);
+  fd = socket(PF_ATMSVC, SOCK_DGRAM, 0);
   if (fd < 0) {
     EVENT(EM_NERR,("Socket failed: %s\n",strerror(errno)));
     return -1;
@@ -891,6 +900,7 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
  
   memset(conn_info , 0, sizeof(CONN_INFO));
 
+  conn_info->conqos.aal = ATM_AAL5;
   conn_info->conqos.txtp.traffic_class = ATM_UBR;
   conn_info->conqos.rxtp.traffic_class = ATM_UBR;
 
@@ -926,7 +936,6 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
     close(fd);
     return -1;
   }
-  conn_info->addr.sas_addr.blli = &conn_info->blli;
   conn_info->blli.l3_proto = ATM_L3_TR9577;
   conn_info->blli.l3.tr9577.ipi = NLPID_IEEE802_1_SNAP;
   conn_info->blli.l3.tr9577.snap[0] = 0x00;
@@ -939,8 +948,16 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
   len = sizeof(struct sockaddr_atmsvc);  
 
   if (EMASK & EM_DEBUG)
-    disp_sockaddr(&conn_info->addr);
-  
+    disp_sockaddr(conn_info);
+
+  memset(&atmsap, 0, sizeof(struct atm_sap));
+  atmsap.blli[0] = conn_info->blli;
+  if (setsockopt(fd,SOL_ATM,SO_ATMSAP,&atmsap,sizeof(atmsap)) < 0) {
+    EVENT(EM_NERR,("conn.c::conn_create_listensocket setsockop(SO_ATMSAP)\n"));
+    (void) close(fd);
+    return -1;
+  }
+
   ret = bind(fd, (struct sockaddr *)&conn_info->addr, len);
   if (ret != 0) {
     EVENT(EM_NERR,("Bind failed: %s\n",strerror(errno)));
