@@ -37,6 +37,7 @@
  *
  */
 #include <linux/atm.h>
+#include "svc_info.h"
 
 const char *disp_status_text (UINT16 status);
 
@@ -48,4 +49,4 @@ void le_frame_display (void   *frame,
                        UINT32  length,
                        const char   *text);
 
-void disp_sockaddr(struct sockaddr_atmsvc *addr);
+void disp_sockaddr(CONN_INFO *p_conn_info);
