@@ -195,6 +195,7 @@ typedef enum
 * Arguments:
 *   lc_elan_handle  - (IN)  Handle of LEC CTRL instance to be used.
 *   esi             - (IN)  48-bit address for LE-ARP.
+*   sizeoftlvs      - (IN)  LANE2: total length of TLVs to send
 *              
 * Returns:
 *   None
@@ -207,7 +208,8 @@ typedef enum
 *
 --*/
 typedef void (*ARP_XMT_CALLBACK) (HANDLE    lc_elan_handle,
-                                  ESI       esi);
+                                  ESI       esi,
+                                  int sizeoftlvs);
 
 /*++
 * ======================
@@ -520,6 +522,8 @@ STATUS la_addr_delete (HANDLE    la_elan_handle,
 *   esi             - (IN) MAC Address in updated mapping.
 *   addr_atm        - (IN) ATM Address in the updated mapping.
 *   remote_flag     - (IN) Remote flag contained in the LE-ARP response frame.
+*   tlv_list        - (IN) LANE2: LE-ARP frames can now contain TLVs
+*   sizeoftlvs      - (IN) LANE2: The length of tlv_list in bytes
 *
 * Returns:
 *   None
@@ -532,11 +536,14 @@ STATUS la_addr_delete (HANDLE    la_elan_handle,
 *   a change from the original mapping (i.e. the ATM address is different from
 *   what was originally in the mapping), the old mapping is discarded and the
 *   flush mechanism is invoked to facilitate the path switch.
+*   LANE2: The TLV association is also up-to-date
 --*/
 void la_arp_update (HANDLE    la_elan_handle,
                     ESI       esi,
                     ADDR_ATM  addr_atm,
-                    BOOLEAN   remote_flag);
+                    BOOLEAN   remote_flag,
+                    char      *tlv_list,
+                    int       sizeoftlvs);
 
 /*++
 * =====================
