@@ -1,10 +1,10 @@
 /* atm.h - Functions useful for ATM applications */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
-#ifndef ATM_H
-#define ATM_H
+#ifndef _ATM_H
+#define _ATM_H
 
 #include <sys/socket.h>
 #include <linux/atm.h>
@@ -12,6 +12,7 @@
 
 #define HOSTS_ATM "/etc/hosts.atm"
 
+/* text2atm flags */
 #define T2A_PVC		  1	/* address is PVC */
 #define T2A_SVC		  2	/* address is SVC */
 #define T2A_UNSPEC	  4	/* allow unspecified parts in PVC address */
@@ -21,22 +22,33 @@
 #define T2A_REMOTE	 64	/* OBSOLETE */
 #define T2A_LOCAL	128	/* don't use ANS */
 
+/* atm2text flags */
 #define A2T_PRETTY	 1	/* add syntactic sugar */
 #define A2T_NAME	 2	/* attempt name lookup */
 #define A2T_REMOTE	 4	/* OBSOLETE */
 #define A2T_LOCAL	 8	/* don't use ANS */
 
+/* atm_equal flags */
 #define AXE_WILDCARD	 1	/* allow wildcard match */
 #define AXE_PRVOPT	 2	/* private part is optional */
 
+/* text2qos flags */
 #define T2Q_DEFAULTS	 1	/* structure contains default values */
 
-#define S2T_NAME	 1	/* attempt name lookup */
-#define S2T_LOCAL	 2	/* we may support NIS or such in the future */
-
+/* text2sap flags */
 #define T2S_NAME	 1	/* attempt name lookup */
 #define T2S_LOCAL	 2	/* we may support NIS or such in the future */
 
+/* sap2text flags */
+#define S2T_NAME	 1	/* attempt name lookup */
+#define S2T_LOCAL	 2	/* we may support NIS or such in the future */
+
+/* sap_equal flags */
+#define SXE_COMPATIBLE	 1	/* check for compatibility instead of identity*/
+#define SXE_NEGOTIATION	 2	/* allow negotiation; requires SXE_COMPATIBLE;
+				   assumes "a" defines the available
+				   capabilities */
+#define SXE_RESULT	 4	/* return selected SAP */
 
 #define MAX_ATM_ADDR_LEN (2*ATM_ESA_LEN+ATM_E164_LEN+5)
 				/* 4 dots, 1 plus */
@@ -58,8 +70,9 @@ int text2qos(const char *text,struct atm_qos *qos,int flags);
 int qos2text(char *buffer,int length,const struct atm_qos *qos,int flags);
 int qos_equal(const struct atm_qos *a,const struct atm_qos *b);
 
-int sap2text(char *buffer,int length,const struct atm_sap *sap,int flags);
 int text2sap(const char *text,struct atm_sap *sap,int flags);
+int sap2text(char *buffer,int length,const struct atm_sap *sap,int flags);
+int sap_equal(const struct atm_sap *a,const struct atm_sap *b,int flags,...);
 
 int __atmlib_fetch(const char **pos,...); /* internal use only */
 
