@@ -1,10 +1,10 @@
 /* atmd.h - Functions useful for demons */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
-#ifndef ATMD_H
-#define ATMD_H
+#ifndef _ATMD_H
+#define _ATMD_H
 
 /*--------------------------- Common definitions ----------------------------*/
 
