@@ -1,15 +1,18 @@
 /* misc.c - Miscellaneous library functions */
 
-/* Written 1997 by Werner Almesberger, EPFL-ICA */
+/* Written 1997,1998 by Werner Almesberger, EPFL-ICA */
 
 
+#include <stdint.h>
 #include <stdarg.h>
 #include <string.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
+#include <netinet/in.h> /* for htons */
 #include <linux/atm.h>
 
 #include <atm.h>
+#include <atmsap.h>
 
 
 int create_leaf(int session)
@@ -46,3 +49,12 @@ int __atmlib_fetch(const char **pos,...)
     if (best > -1) (*pos) += best_len;
     return best;
 }
+
+
+void atm_tcpip_port_mapping(char *vs_id,uint8_t protocol,uint16_t port)
+{
+    memcpy(vs_id,ATM_FORUM_OUI "\x01",4);
+    vs_id[4] = protocol; /* e.g. IP_TCP or IP_UDP; from netinet/protocols.h */
+    vs_id[5] = (htons(port) >> 8) & 255;
+    vs_id[6] = htons(port) & 255;
+}
