@@ -1,6 +1,6 @@
 /* sdu2cr.c - Converts SDU sizes and SDU counts to cell counts */
 
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <limits.h>
@@ -11,13 +11,13 @@
 
 int sdu2cell(int s,int sizes,const int *sdu_size,int *num_sdu)
 {
-    unsigned char aal;
+    struct atm_qos qos;
     int trailer,total,cells;
     int size,i;
 
-    size = sizeof(aal);
-    if (getsockopt(s,SOL_AAL,SO_AALTYPE,&aal,&size) < 0) return -1;
-    switch (aal) {
+    size = sizeof(qos);
+    if (getsockopt(s,SOL_AAL,SO_ATMQOS,&qos,&size) < 0) return -1;
+    switch (qos.aal) {
 	case ATM_AAL0:
 	    trailer = 0;
 	    break;
