@@ -150,8 +150,6 @@ static int try_nsap(const char *text,struct sockaddr_atmsvc *addr,int flags)
     result = do_try_nsap(text,addr,flags);
     if (result < 0) return result;
     addr->sas_family = AF_ATMSVC;
-    addr->sas_addr.bhli.hl_type = ATM_HL_NONE;
-    addr->sas_addr.blli = NULL;
     *addr->sas_addr.pub = 0;
     return result;
 }
@@ -184,8 +182,6 @@ static int try_e164(const char *text,struct sockaddr_atmsvc *addr,int flags)
 	    if (result < 0) return FATAL;
 	}
     addr->sas_family = AF_ATMSVC;
-    addr->sas_addr.bhli.hl_type = ATM_HL_NONE;
-    addr->sas_addr.blli = NULL;
     return result;
 }
 
