@@ -1,11 +1,12 @@
 /* atmtcp.c - control ATM on TCP emulation */
 
-/* Written 1995,1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <errno.h>
 #include <netdb.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -62,8 +63,8 @@ static void from_tcp(void)
     bytes += ret;
     if (bytes < sizeof(struct atmtcp_hdr)) return;
     if (ntohl(((struct atmtcp_hdr *) buf)->length) > ATM_MAX_AAL5_PDU) {
-	fprintf(stderr,"giant PDU (length = %ld) received\n",
-	  ntohl(((struct atmtcp_hdr *) buf)->length));
+	fprintf(stderr,"giant PDU (length = %d) received\n",
+	  (unsigned int) ntohl(((struct atmtcp_hdr *) buf)->length));
 	exit(1);
     }
     if (bytes < sizeof(struct atmtcp_hdr)+
