@@ -339,6 +339,7 @@ int q_read(Q_DSC *dsc,int field,void *buf,int size)
 {
     int len;
 
+    len = 0; /* for gcc */
     if (field < 0 || field >= Q_FIELDS)
 	PREFIX(report)(Q_FATAL,"invalid field value (%d)",field);
     field = dsc->field_map[field];
@@ -361,6 +362,15 @@ int q_read(Q_DSC *dsc,int field,void *buf,int size)
 
 void q_instance(Q_DSC *dsc,int group)
 {
+    int i;
+
+    if (group >= 0 || group < -Q_GROUPS)
+	PREFIX(report)(Q_FATAL,"invalid group number (%d)",group);
+    if (groups[-group-1].start == -1)
+	PREFIX(report)(Q_FATAL,"group %d is unique",group);
+    for (i = 0; i < groups[-group-1].length; i++)
+	dsc->field_map[groups[-group-1].start+i] = groups[-group-1].start+i+
+	  groups[-group-1].offset;
 }
 
 
@@ -792,6 +802,7 @@ int PREFIX(close)(Q_DSC *dsc)
 {
     int size;
 
+    size = 0; /* for gcc */
 #ifndef DUMP_MODE
     if (dsc->buffer && !dsc->error)
 	size = q_compose(dsc,dsc->buffer,dsc->buf_size);
