@@ -1,11 +1,13 @@
 /* sscop.h - SSCOP (Q.2110) user interface */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #ifndef SSCOP_H
 #define SSCOP_H
 
+#include <stdint.h>
+
 #include "atmd.h"
 
 #include "queue.h"
@@ -47,7 +49,7 @@ typedef struct {
     QUEUE tx_buf,tx_q,rx_buf,rt_q;
     BUFFER *last_bgn,*last_end,*last_rs,*last_er; /* for retransmission */
     /* Misc items */
-    __u32 *list; /* STAT construction list */
+    uint32_t *list; /* STAT construction list */
 } SSCOP_DSC;
 
 
