@@ -1,6 +1,6 @@
 /* atmsigd.c - ATM signaling demon */
 
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -31,6 +31,7 @@ extern int yyparse(void);
 extern FILE *yyin;
 
 int net = 0;
+int allocate_ci = 1;
 int debug = 0;
 int pretty = A2T_PRETTY | A2T_NAME | A2T_LOCAL;
 int sig_pcr = -1; /* obsolete */
@@ -282,7 +283,7 @@ static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s [ -b ] [ -c config_file ] [ -d ] "
       "[ -D dump_dir ]\n"
-      "  [ -l logfile ] [ -n ] [ -N ]  [ -q qos ] [ -t trace_length ]\n"
+      "  [ -l logfile ] [ -n ] [ -N [ -A ] ]  [ -q qos ] [ -t trace_length ]\n"
       "  [ [itf.]vpi.vci [ input output ] ]\n",name);
     exit(1);
 }
@@ -301,7 +302,7 @@ int main(int argc,char **argv)
     memset(&signaling_pvc,0,sizeof(signaling_pvc));
     signaling_pvc.sap_addr.vci = 5;
     /* 1st pass to get the -c option */
-    while ((c = getopt(argc,argv,"bc:dD:l:nNP:q:t:")) != EOF)
+    while ((c = getopt(argc,argv,"Abc:dD:l:nNP:q:t:")) != EOF)
 	if (c == 'c') config_file = optarg;
     if (!(yyin = fopen(config_file,"r")))
 	diag(COMPONENT,DIAG_WARN,"%s not found. - Using defaults.",config_file);
@@ -311,8 +312,11 @@ int main(int argc,char **argv)
 	}
     /* process all other options but -c */
     optind = 0;
-    while ((c = getopt(argc,argv,"bc:dD:l:nNP:q:t:")) != EOF)
+    while ((c = getopt(argc,argv,"Abc:dD:l:nNP:q:t:")) != EOF)
 	switch (c) {
+	    case 'A':
+		allocate_ci = 0;
+		break;
 	    case 'b':
 		background = 1;
 		break;
@@ -355,6 +359,7 @@ int main(int argc,char **argv)
 	    default:
 		usage(argv[0]);
 	}
+    if (!allocate_ci && !net) usage(argv[0]);
     if (optind < argc) {
 	if (text2atm(argv[optind],(struct sockaddr *) &signaling_pvc,
 	  sizeof(signaling_pvc),T2A_PVC) < 0)
