@@ -1,6 +1,6 @@
 /* proto.h - Common protocol functions and structures */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC */
  
 
 #ifndef PROTO_H
@@ -16,6 +16,7 @@ typedef enum { /* formatting aligned with state_map and others */
 	ss_invalid,	ss_null,	ss_listening,	ss_connecting,
 	ss_connected,	ss_indicated,	ss_accepting,	ss_zombie,
 	ss_wait_rel,	ss_wait_close,	ss_rel_req,	ss_rel_ind,
+	ss_proceeding,	ss_listen_zombie,
 #ifdef Q2963_1
 	ss_mod_lcl,	ss_mod_req,	ss_mod_rcv,	ss_mod_fin_ack,
 	ss_mod_fin_ok,	ss_mod_fin_fail
@@ -73,6 +74,7 @@ extern unsigned char q_buffer[];
 #define DEFAULT_TRACE_SIZE 20
 
 extern int net;
+extern int allocate_ci;
 extern int pretty;
 extern int sig_pcr;
 extern const char *sig_qos;
@@ -109,6 +111,7 @@ SOCKET *lookup_sap(const struct sockaddr_atmsvc *addr,
 
 void send_release(SOCKET *sock,unsigned char reason,...);
 void send_release_complete(unsigned long call_ref,unsigned char cause);
+int send_call_proceeding(SOCKET *sock);
 void send_modify_reject(SOCKET *sock,unsigned char reason);
 
 const char *mid2name(unsigned char mid);
