@@ -1,12 +1,13 @@
 /* uni.c - Processing of incoming UNI signaling messages */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdarg.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
 #include <assert.h>
 #include <linux/atmdev.h>
 
@@ -23,9 +24,6 @@
 #include "timeout.h"
 #include "trace.h"
 
-#define __KERNEL__ /* since that's what we effectively are */
-#include <linux/errno.h>
-
 
 #define COMPONENT "UNI"
 
@@ -37,7 +35,7 @@ static Q_DSC in_dsc;
 static TIMER *t309 = NULL;
 
 
-static int send_call_proceeding(SOCKET *sock)
+int send_call_proceeding(SOCKET *sock)
 {
     Q_DSC dsc;
     int size;
@@ -45,7 +43,7 @@ static int send_call_proceeding(SOCKET *sock)
     q_create(&dsc,q_buffer,MAX_Q_MSG);
     q_assign(&dsc,QF_msg_type,ATM_MSG_CALL_PROC);
     q_assign(&dsc,QF_call_ref,sock->call_ref);
-    if (net) {
+    if (net && allocate_ci) {
 	int vci;
 
 	vci = get_vci(0);
@@ -53,12 +51,14 @@ static int send_call_proceeding(SOCKET *sock)
 	    (void) q_close(&dsc);
 	    return vci;
 	}
-	q_assign(&dsc,QF_vpi,0); /* @@@ */
-	q_assign(&dsc,QF_vci,vci);
 	sock->pvc.sap_addr.itf = signaling_pvc.sap_addr.itf;
 	sock->pvc.sap_addr.vpi = 0;
 	sock->pvc.sap_addr.vci = vci;
     }
+    if (net) {
+	q_assign(&dsc,QF_vpi,sock->pvc.sap_addr.vpi);
+	q_assign(&dsc,QF_vci,sock->pvc.sap_addr.vci);
+    }
     if (sock->ep_ref >= 0) q_assign(&dsc,QF_ep_ref,sock->ep_ref);
     if ((size = q_close(&dsc)) >= 0) to_signaling(q_buffer,size);
     return 0;
@@ -91,7 +91,7 @@ static void setup_call(unsigned long call_ref)
 	return;
     }
     this->qos.aal = ATM_AAL5; /* hack @@@ */
-    this->state = ss_indicated;
+    this->state = net && allocate_ci ? ss_proceeding : ss_indicated;
     this->call_state = cs_in_proc;
     this->call_ref = call_ref;
     if (q_present(&in_dsc,QF_ep_ref))
@@ -99,7 +99,7 @@ static void setup_call(unsigned long call_ref)
 #ifdef CISCO
     else
 #endif
-    {
+    if (net && allocate_ci) {
 	int error;
 
 	error = send_call_proceeding(this);
@@ -148,7 +148,7 @@ static void setup_call(unsigned long call_ref)
 	    diag(COMPONENT,DIAG_DEBUG,"Incoming call from %s",buffer);
 	}
     }
-    send_kernel(0,sock->id,as_indicate,0,&this->pvc,&this->remote,NULL,
+    send_kernel(0,sock->id,as_indicate,0,&this->pvc,&this->remote,&in_addr,
       &this->sap,&this->qos);
     for (walk = &sock->listen; *walk; walk = &(*walk)->listen);
     *walk = this;
@@ -400,7 +400,10 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 		case ss_accepting:
 		    set_error(sock,-ECONNRESET); /* ERESTARTSYS ? */
 		    send_release_complete(sock->call_ref,0);
-		    /* fall through */
+		    SEND_ERROR(sock->id,sock->error);
+		    STOP_TIMER(sock);
+		    free_sock(sock);
+		    return;
 		case ss_rel_req:
 		    send_close(sock);
 		    /* fall through */
@@ -431,11 +434,12 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 		    new_state(sock,ss_rel_ind);
 		    return;
 		case ss_indicated:
+		    /* fall through */
+		case ss_proceeding:
 		    send_release_complete(sock->call_ref,0);
 		    new_state(sock,ss_zombie);
 		    /* fall through */
 		case ss_rel_ind:
-		    /* send_release_complete(sock->call_ref,0); */
 		    return;
 		default:
 		    send_release_complete(sock->call_ref,0); /* @@@ should
@@ -473,7 +477,10 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 			/* fall through */
 		    case ss_accepting:
 			set_error(sock,-ECONNRESET); /* ERESTARTSYS ? */
-			/* fall through */
+			SEND_ERROR(sock->id,sock->error);
+			STOP_TIMER(sock);
+			free_sock(sock);
+			return;
 		    case ss_rel_req:
 			send_close(sock);
 			/* fall through */
@@ -506,6 +513,8 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 			new_state(sock,ss_wait_close);
 			return;
 		    case ss_indicated:
+			/* fall through */
+		    case ss_proceeding:
 			new_state(sock,ss_zombie);
 			return;
 		    default:
@@ -713,14 +722,19 @@ static void process_uni(void *msg)
 }
 
 
-static void abort_call(void)
+static void abort_call(unsigned char *msg,int size)
 {
     SOCKET *curr;
     unsigned long call_ref;
 
-    diag(COMPONENT,DIAG_ERROR,"can't parse message - aborting the call");
-    call_ref = q_fetch(&in_dsc,QF_call_ref)^0x800000;
-	/* hope that at least the call ref was okay ... */
+    if (size < 6) {
+	diag(COMPONENT,DIAG_ERROR,"message too short (%d bytes)",size);
+	return;
+    }
+    /* hope that at least the call ref is okay ... */
+    call_ref = ((msg[3] << 16) | (msg[4] << 8) | msg[5])^0x800000;
+    diag(COMPONENT,DIAG_ERROR,"can't parse message - aborting the call "
+      "(CR 0x%06lx)",call_ref);
     for (curr = sockets; curr; curr = curr->next)
         if (curr->call_ref == call_ref) {
 	    uni_call(curr,ATM_MSG_RESTART);
@@ -733,7 +747,7 @@ static void abort_call(void)
 void to_uni(void *msg,int size)
 {
     if (q_open(&in_dsc,msg,size) < 0) {
-	abort_call();
+	abort_call(msg,size);
 	return;
     }
     process_uni(msg);
